@@ -1,11 +1,11 @@
 /*  File src/ergmm_latent_effects.h in package latentnet, part of the Statnet suite
- *  of packages for network analysis, http://statnet.org .
+ *  of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  http://statnet.org/attribution
+ *  https://statnet.org/attribution
  *
- *  Copyright 2003-2018 Statnet Commons
+ *  Copyright 2003-2020 Statnet Commons
  */
 #ifndef ERGMM_LATENT_EFFECTS_H
 #define ERGMM_LATENT_EFFECTS_H
@@ -13,7 +13,9 @@
 #define N_LATENT_EFF 3
 
 /* Declare "lookup tables" for latent effects. */
-double (*ERGMM_MCMC_latent_eff[N_LATENT_EFF])(double *u, double *v, unsigned int dim);
+typedef double (*ERGMM_MCMC_latent_eff_t)(double *u, double *v, unsigned int dim);
+
+extern ERGMM_MCMC_latent_eff_t ERGMM_MCMC_latent_eff[];
 
 /* Latent effect # */
 /* 0 */ 
