@@ -1,11 +1,11 @@
 /*  File src/ergmm_sampler.c in package latentnet, part of the Statnet suite
- *  of packages for network analysis, http://statnet.org .
+ *  of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  http://statnet.org/attribution
+ *  https://statnet.org/attribution
  *
- *  Copyright 2003-2018 Statnet Commons
+ *  Copyright 2003-2020 Statnet Commons
  */
 /****************************************************************************/
 /* Top-level functions for sampling from an ERGMM's posterior distribution. */
@@ -478,7 +478,9 @@ void ERGMM_MCMC_loop(ERGMM_MCMC_Model *model, ERGMM_MCMC_Priors *prior,
       ERGMM_MCMC_store_iteration(pos, model, cur->state, setting, outlists);
 
       // Acceptance rates.
-      outlists->coef_rate[pos] = (double) ((double)n_accept_b)/((double)setting->interval);
+      if(outlists->coef_rate){
+        outlists->coef_rate[pos] = (double) ((double)n_accept_b)/((double)setting->interval);
+      }
       if(outlists->Z_rate_move){
 	outlists->Z_rate_move[pos] = (double) ((double)n_accept_z)/((double)setting->interval*model->verts); 
       }
